@@ -5,14 +5,14 @@ use strict;
 use warnings;
 use WebService::Hexonet::Connector::ResponseParser;
 
-use version 0.9917; our $VERSION = version->declare('v2.2.4');
+use version 0.9917; our $VERSION = version->declare('v2.3.0');
 
 
 sub new {
     my ( $class, $raw ) = @_;
     my $self = {};
     if ( !defined $raw || length $raw == 0 ) {
-        $raw = "[RESPONSE]\r\nCODE=423\r\nDESCRIPTION=Empty API response\r\nEOF\r\n";
+        $raw = "[RESPONSE]\r\nCODE=423\r\nDESCRIPTION=Empty API response. Probably unreachable API end point\r\nEOF\r\n";
     }
     $self->{raw}  = $raw;
     $self->{hash} = WebService::Hexonet::Connector::ResponseParser::parse($raw);
@@ -109,17 +109,20 @@ To be used in the way:
 
     # specify the API plain-text response (this is just an example that won't fit to the command above)
     $plain = "[RESPONSE]\r\nCODE=200\r\nDESCRIPTION=Command completed successfully\r\nEOF\r\n";
-  
+
     # create a new instance
     $r = WebService::Hexonet::Connector::ResponseTemplate->new($plain);
 
 The difference of this library and the Response library is simply that this library
 
 =over
+
 =item *
 does not provide further data access possibilities based on Column and Record library
+
 =item *
 does not require an API command to be specified in constructor
+
 =back
 
 =head1 DESCRIPTION
